@@ -71,10 +71,10 @@ class RedisSimple():
             key = pickle.dumps(key_name)
             rs = RedisSimple()
             result_set = rs.conn.get(key)
-            data = pickle.loads(rs.get(key))
+            data = pickle.loads(result_set)
             if data:
                 print('Returning resultset deserialized object')
-                return json.loads(data)
+                return data
             else:
                 raise RedisSimpleException(ResponseCode.KEY_NOT_FOUND,
                                            ResponseCode.getResponseMsg(ResponseCode.KEY_NOT_FOUND))
